#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>

typedef struct i {
  char name[32];
  struct i *lst;	// contents
  struct i *nxt;
} instr_t;

#define IS_I(i)		(*(uint16_t *)(i)->name == 'I')
#define IS_C(i)		(*(uint16_t *)(i)->name >= 'a')

void freeinst(instr_t *i)
{
  for (instr_t *n; i; i = n) {
    if (IS_C(i)) freeinst(i->lst);
    n = i->nxt;
    free(i);
  }
}

void print(instr_t *i)
{
  if (IS_C(i)) {
      printf ("%s [ ", i->name);
      for (instr_t *c = i->lst; c; c = c->nxt) print(c);
      fputs("] ", stdout);
  } else { putchar(*i->name+32); putchar(' '); }	// tolower
}

int read_prog(instr_t **fst)	// address for result
{
  instr_t **pi = fst;		// write at tail 
  int keep = 0;			// interesting ?
  while (*pi = malloc(sizeof(instr_t)), scanf(" %30[a-z] ", (*pi)->name) == 1) {
    int c = getchar();
    if (c == '[') {
      if (read_prog(&(*pi)->lst)) keep = 1;
      else { freeinst((*pi)->lst); (*pi)->lst = NULL; }
      if (getchar() != ']') exit(1);
    } else {
      if (c != EOF) ungetc(c, stdin);
      *(*pi)->name -= 32;	// toupper
      if (IS_I(*pi)) keep = 1;
    }
    pi = &(*pi)->nxt;		// update tail address
  }
  if (*pi) { free(*pi); *pi = NULL; }	// memory for failed read
  return keep;
}

int main(void)
{
  freopen("program.in", "r", stdin);
  freopen("program.out", "w", stdout);
  instr_t *p = NULL;
  read_prog(&p);
  for (instr_t *i = p; i; i = i->nxt) print(i);
  freeinst(p);
  return 0;
}
